@@ -1,6 +1,6 @@
 package JE::String;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 
 use strict;
@@ -10,9 +10,16 @@ use overload fallback => 1,
 	'""' => 'value',
 	 cmp =>  sub { "$_[0]" cmp $_[1] };
 
+use Memoize;
+memoize('desurrogify', LIST_CACHE => 'MERGE');
+
+our @ISA = 'Exporter';
+our @EXPORT_OK = 'desurrogify';
+
 require JE::Object::String;
 require JE::Boolean;
 require JE::Number;
+require Exporter;
 
 
 sub new {
@@ -41,7 +48,8 @@ sub new {
 sub prop {
 	# ~~~ if length is readonly and undeletable, I can deal with it
 	#     here.
-	 # ~~~ Make prop simply return the value if there is one.
+	 # ~~~ Make prop simply return the value if the prototype has that
+	 #      property.
 	my $self = shift;
 	JE::Object::String->new($$self[1], $self)->prop(@_);
 }
@@ -62,17 +70,10 @@ sub method {
 }
 
 
-sub value {  # unsurrogify:
-	my $ret = shift->[0];
-	$ret =~ s/([\x{d800}-\x{dbff}])([\x{dc00}-\x{dfff}])/
-		chr 0x10000 + ($1 - 0xD800) * 0x400 + ($2 - 0xDC00)
-	/ge;
-	$ret;
- }
+sub value {
+	desurrogify($_[0][0]);
+}
 
-sub call   { die }
-sub apply  { die }
-sub construct { die }
 
 sub typeof    { 'string' }
 sub id        { 'str:' . $_[0][0] }
@@ -108,6 +109,16 @@ sub to_number  {
 sub global { $_[0][1] }
 
 
+sub desurrogify($) {
+	my $ret = shift;
+#warn join ',' ord
+	$ret =~ s/([\x{d800}-\x{dbff}])([\x{dc00}-\x{dfff}])/
+		chr 0x10000 + ($1 - 0xD800) * 0x400 + ($2 - 0xDC00)
+	/ge;
+	$ret;
+}
+
+
 1;
 __END__
 
@@ -137,6 +148,21 @@ I<objects,> while this module implements the I<primitive> values.
 
 The stringification operator is overloaded.
 
+=head1 THE FUNCTION
+
+There is one exportable function, C<desurrogify>, which will convert
+surrogate pairs in its string input argument into the characters they
+represent, and return the modified string. E.g.:
+
+  use JE::String 'desurrogify';
+  
+  {
+          no warnings 'utf8';
+          $str = "\x{d834}\x{dd2b}";
+  }
+
+  $str = desurrogify $str;  # $str now contains "\x{1d12b}" (double flat)
+
 =head1 SEE ALSO
 
 =over 4
